@@ -20,6 +20,8 @@ class TaskContext:
     async def my_task(ctx: TaskContext, data: dict):
         print(f"Task ID: {ctx.event_id}")
         print(f"Task Name: {ctx.name}")
+        if ctx.scheduled_task_id:
+            print(f"Triggered by scheduled task: {ctx.scheduled_task_id}")
         return data
     """
     event_id: str
@@ -29,6 +31,7 @@ class TaskContext:
     queue: Optional[str] = None
     worker_id: Optional[str] = None
     retry_count: int = 0
+    scheduled_task_id: Optional[int] = None  # 定时任务ID（如果由定时任务触发）
     
     def __repr__(self) -> str:
         return f"TaskContext(event_id={self.event_id}, name={self.name}, queue={self.queue})"
\ No newline at end of file
